@@ -1,4 +1,4 @@
 # Application Settings
 ADMIN_ROLE = "SpellBot Admin"
 CREATE_ENDPOINT = "https://us-central1-magic-night-30324.cloudfunctions.net/createGame"
-AVG_QUEUE_TIME_WINDOW_MIN = 30
+THUMB_URL = "https://raw.githubusercontent.com/lexicalunit/spellbot/master/spellbot.png"
